[llvm-commits] [llvm] r98210 - /llvm/trunk/lib/Target/ARM/ARMSubtarget.h

Bob Wilson bob.wilson at apple.com
Wed Mar 10 16:20:49 PST 2010


Author: bwilson
Date: Wed Mar 10 18:20:49 2010
New Revision: 98210

URL: http://llvm.org/viewvc/llvm-project?rev=98210&view=rev
Log:
Lower small memcpys to load/stores on Thumb2.
Radar 7686922.

Modified:
    llvm/trunk/lib/Target/ARM/ARMSubtarget.h

Modified: llvm/trunk/lib/Target/ARM/ARMSubtarget.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Target/ARM/ARMSubtarget.h?rev=98210&r1=98209&r2=98210&view=diff
==============================================================================
--- llvm/trunk/lib/Target/ARM/ARMSubtarget.h (original)
+++ llvm/trunk/lib/Target/ARM/ARMSubtarget.h Wed Mar 10 18:20:49 2010
@@ -94,9 +94,9 @@
   /// getMaxInlineSizeThreshold - Returns the maximum memset / memcpy size
   /// that still makes it profitable to inline the call.
   unsigned getMaxInlineSizeThreshold() const {
-    // FIXME: For now, we don't lower memcpy's to loads / stores for Thumb.
-    // Change this once Thumb ldmia / stmia support is added.
-    return isThumb() ? 0 : 64;
+    // FIXME: For now, we don't lower memcpy's to loads / stores for Thumb1.
+    // Change this once Thumb1 ldmia / stmia support is added.
+    return isThumb1Only() ? 0 : 64;
   }
   /// ParseSubtargetFeatures - Parses features string setting specified
   /// subtarget options.  Definition of function is auto generated by tblgen.





More information about the llvm-commits mailing list